@@ -23,9 +23,11 @@ from botocore.exceptions import NoCredentialsError
 from botocore.exceptions import NoRegionError
 
 from awscli import EnvironmentVariables, __version__
+from awscli.compat import get_stderr_text_writer
 from awscli.formatter import get_formatter
 from awscli.plugin import load_plugins
 from awscli.commands import CLICommand
+from awscli.compat import six
 from awscli.argparser import MainArgParser
 from awscli.argparser import ServiceArgParser
 from awscli.argparser import ArgTableArgParser
@@ -219,8 +221,10 @@ class CLIDriver(object):
         except Exception as e:
             LOG.debug("Exception caught in main()", exc_info=True)
             LOG.debug("Exiting with rc 255")
-            sys.stderr.write("\n")
-            sys.stderr.write("%s\n" % e)
+            err = get_stderr_text_writer()
+            err.write("\n")
+            err.write(six.text_type(e))
+            err.write("\n")
             return 255
 
     def _emit_session_event(self):
